@@ -574,6 +574,12 @@ class OrderController
                 'order' => $orderObject->newOrderData(),
                 'coupons' => $coupons,
                 'notes' => $order->get_customer_note() ?: 'No note',
+                'shipping' => [
+                    $order->shipping_address_1,
+                    $order->shipping_address_2,
+                    $order->shipping_city,
+                    $order->shipping_postcode,
+                ],
                 'orderItems' => [],
             ];
         }
@@ -634,6 +640,12 @@ class OrderController
                         $orderData[$orderId] = [
                             'order' => $order->newOrderData(),
                             'coupons' => $coupons,
+                            'shipping' => [
+                                $wcOrder->shipping_address_1,
+                                $wcOrder->shipping_address_2,
+                                $wcOrder->shipping_city,
+                                $wcOrder->shipping_postcode,
+                            ],
                             'orderItems' => [],
                             'notes' => $wcOrder->get_customer_note() ?: 'No note',
                         ];
